@@ -1,9 +1,7 @@
 package Crypt::Curve25519;
-BEGIN {
-  $Crypt::Curve25519::AUTHORITY = 'cpan:AJGB';
-}
+our $AUTHORITY = 'cpan:AJGB';
 #ABSTRACT: Generate shared secret using elliptic-curve Diffie-Hellman function
-$Crypt::Curve25519::VERSION = '0.04';
+$Crypt::Curve25519::VERSION = '0.05';
 use strict;
 use warnings;
 use Carp qw( croak );
@@ -83,7 +81,7 @@ Crypt::Curve25519 - Generate shared secret using elliptic-curve Diffie-Hellman f
 
 =head1 VERSION
 
-version 0.04
+version 0.05
 
 =head1 SYNOPSIS
 
